@@ -3,34 +3,72 @@
 /*  coded open read* write* and close.  
  *  largly from helping Jim Garvin get a simple example working.
  *  everything else needs work. TJ */
-
 /*-------------------------------------------------------------------------
-|   rxtx is a native interface to i2c ports in java.
-|   Copyright 1997-2002 by Trent Jarvi taj@www.linux.org.uk
+|   RXTX License v 2.1 - LGPL v 2.1 + Linking Over Controlled Interface.
+|   RXTX is a native interface to serial ports in java.
+|   Copyright 1997-2007 by Trent Jarvi tjarvi@qbang.org and others who
+|   actually wrote it.  See individual source files for more information.
+|
+|   A copy of the LGPL v 2.1 may be found at
+|   http://www.gnu.org/licenses/lgpl.txt on March 4th 2007.  A copy is
+|   here for your convenience.
 |
 |   This library is free software; you can redistribute it and/or
-|   modify it under the terms of the GNU Library General Public
+|   modify it under the terms of the GNU Lesser General Public
 |   License as published by the Free Software Foundation; either
-|   version 2 of the License, or (at your option) any later version.
+|   version 2.1 of the License, or (at your option) any later version.
 |
 |   This library is distributed in the hope that it will be useful,
 |   but WITHOUT ANY WARRANTY; without even the implied warranty of
 |   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-|   Library General Public License for more details.
+|   Lesser General Public License for more details.
 |
-|   You should have received a copy of the GNU Library General Public
+|   An executable that contains no derivative of any portion of RXTX, but
+|   is designed to work with RXTX by being dynamically linked with it,
+|   is considered a "work that uses the Library" subject to the terms and
+|   conditions of the GNU Lesser General Public License.
+|
+|   The following has been added to the RXTX License to remove
+|   any confusion about linking to RXTX.   We want to allow in part what
+|   section 5, paragraph 2 of the LGPL does not permit in the special
+|   case of linking over a controlled interface.  The intent is to add a
+|   Java Specification Request or standards body defined interface in the 
+|   future as another exception but one is not currently available.
+|
+|   http://www.fsf.org/licenses/gpl-faq.html#LinkingOverControlledInterface
+|
+|   As a special exception, the copyright holders of RXTX give you
+|   permission to link RXTX with independent modules that communicate with
+|   RXTX solely through the Sun Microsytems CommAPI interface version 2,
+|   regardless of the license terms of these independent modules, and to copy
+|   and distribute the resulting combined work under terms of your choice,
+|   provided that every copy of the combined work is accompanied by a complete
+|   copy of the source code of RXTX (the version of RXTX used to produce the
+|   combined work), being distributed under the terms of the GNU Lesser General
+|   Public License plus this exception.  An independent module is a
+|   module which is not derived from or based on RXTX.
+|
+|   Note that people who make modified versions of RXTX are not obligated
+|   to grant this special exception for their modified versions; it is
+|   their choice whether to do so.  The GNU Lesser General Public License
+|   gives permission to release a modified version without this exception; this
+|   exception also makes it possible to release a modified version which
+|   carries forward this exception.
+|
+|   You should have received a copy of the GNU Lesser General Public
 |   License along with this library; if not, write to the Free
 |   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+|   All trademarks belong to their respective owners.
 --------------------------------------------------------------------------*/
 #ifdef __STRICT_ANSI__
 #undef __STRICT_ANSI__
 #endif
-#if defined(__MWERKS__)//dima
+#if defined(__MWERKS__)/* dima */
 #include "Raw.h"
-#else//dima
+#else /* dima */
 #include "config.h"
 #include "gnu_io_Raw.h"
-#endif//dima
+#endif /* dima */
 #include <time.h>
 #include <unistd.h>
 #include <stdio.h>
@@ -61,9 +99,11 @@
 #	include <linux/serial.h>
 #	include <linux/version.h>
 #endif
-#ifndef __APPLE__ //dima
+#ifndef __APPLE__  /* dima */
+#ifndef PPC
 #include <sys/io.h>
-#endif//dima
+#endif /* PPC */
+#endif /* dima */
 
 extern int errno;
 #include "I2CImp.h"
@@ -194,8 +234,7 @@ RawPort.Java_Bus_read32
    return:      none
    exceptions:  none
 ----------------------------------------------------------*/
-//////////////////////////////////////////////////////////
-// This Function is called from Java to write to an 32 bit bus
+/*  This Function is called from Java to write to a 32 bit bus */
 JNIEXPORT void JNICALL Java_Bus_write32
   (JNIEnv * env, jobject poObj, jint piPort, jint piData)
 {
@@ -265,9 +304,9 @@ JNIEXPORT void JNICALL Java_gnu_io_RawPort_nativeSetRawPortParams(
 	int cspeed = translate_speed( env, speed );
 	if( !cspeed ) return;
 	if( tcgetattr( fd, &ttyset ) < 0 ) goto fail;
-	if( !translate_data_bits( env, (int *)&(ttyset.c_cflag), dataBits ) ) return;//dima c_flag darwin unsigned long
-	if( !translate_stop_bits( env, (int *)&(ttyset.c_cflag), stopBits ) ) return;//dima c_flag darwin unsigned long
-	if( !translate_parity( env, (int *)&(ttyset.c_cflag), parity ) ) return;//dima c_flag darwin unsigned long
+	if( !translate_data_bits( env, (int *)&(ttyset.c_cflag), dataBits ) ) return; /* dima c_flag darwin unsigned long */
+	if( !translate_stop_bits( env, (int *)&(ttyset.c_cflag), stopBits ) ) return; /* dima c_flag darwin unsigned long */
+	if( !translate_parity( env, (int *)&(ttyset.c_cflag), parity ) ) return;/* dima c_flag darwin unsigned long */
 #ifdef __FreeBSD__
 	if( cfsetspeed( &ttyset, cspeed ) < 0 ) goto fail;
 #else
@@ -906,7 +945,7 @@ JNIEXPORT jint JNICALL Java_gnu_io_RawPort_readArray( JNIEnv *env,
 	int fd = get_java_var( env, jobj, "fd", "I" );
 	int timeout = get_java_var( env, jobj, "timeout", "I" );
 
-	if( length > SSIZE_MAX || length < 0 ) {
+	if( (size_t) length > SSIZE_MAX || (size_t) length < 0 ) {
 		throw_java_exception( env, ARRAY_INDEX_OUT_OF_BOUNDS,
 			"readArray", "Invalid length" );
 		return -1;
@@ -1027,7 +1066,7 @@ JNIEXPORT void JNICALL Java_gnu_io_RawPort_eventLoop( JNIEnv *env,
 	jboolean interrupted = 0;
 	jclass jclazz, jthread;
 	jclazz = (*env)->GetObjectClass( env, jobj );
-	fd = fd = get_java_var(env, jobj, "fd", "I");
+	fd = get_java_var(env, jobj, "fd", "I");
 	method = (*env)->GetMethodID( env, jclazz, "sendEvent", "(IZ)V" );
 	jthread = (*env)->FindClass( env, "java/lang/Thread" );
 	interrupt = (*env)->GetStaticMethodID( env, jthread, "interrupted", "()Z" );
